OC.L10N.register(
    "privacy",
    {
    "Privacy" : "Privatnost",
    "-" : "-",
    "The privacy center shows you where your data is stored and who can access it, either because you shared with them or because they are administrators." : "Centar privatnosti vam pokazuje gdje se vaši podaci pohranjuju i tko im može pristupiti jer ste ih podijelili ili zato što se radi o administratorima.",
    "Administrators" : "Administratori",
    "Add external admin" : "Dodaj vanjskog administratora",
    "Cancel" : "Odustani",
    "Add" : "Dodaj",
    "Name of external admin" : "Ime vanjskog administratora",
    "Encryption" : "Šifriranje",
    "Edit" : "Uredi",
    "This server is using full-disk-encryption." : "Ovaj poslužitelj koristi šifriranje cijelog diska.",
    "Your files on external storages may be encrypted using {linkopen}server-side-encryption ↗{linkclose} with a master key based on their configuration." : "Vaše datoteke na vanjskim spremištima za pohranu mogu se {linkopen}šifrirati na poslužitelju ↗{linkclose} s pomoću glavnog ključa na temelju njihove konfiguracije.",
    "Your files on external storages may be encrypted using {linkopen}server-side-encryption ↗{linkclose} with an individual key based on their configuration." : "Vaše datoteke na vanjskim spremištima za pohranu mogu se {linkopen}šifrirati na poslužitelju ↗{linkclose} s pomoću odgovarajućeg ključa na temelju njihove konfiguracije.",
    "Additionally, this server is protected with full-disk-encryption." : "Ovaj je poslužitelj također zaštićen šifriranjem cijelog diska.",
    "This server is protected with full-disk-encryption." : "Ovaj je poslužitelj zaštićen šifriranjem cijelog diska.",
    "Your files are not protected by encryption." : "Vaše datoteke nisu zaštićene šifriranjem.",
    "Privacy policy" : "Pravila o privatnosti",
    "Who has access to your data?" : "Tko ima pristup vašim podacima?",
    "Where is your data?" : "Gdje su vaši podaci?",
    "Your data is located in:" : "Vaši se podaci nalaze u:",
    "Change data location" : "Promijeni lokaciju podataka",
    "Region" : "Regija",
    "Please select a region" : "Odaberite regiju",
    "User Data Manifesto 2.0" : "Manifest o podacima korisnika 2.0",
    "Control" : "Kontrola",
    "over user data access" : "pristupa podacima korisnika",
    "Data explicitly and willingly uploaded by a user should be under the ultimate control of the user. Users should be able to decide whom to grant direct access to their data and with which permissions and licenses such access should be granted." : "Podaci koje korisnik neposredno i voljno otpremi moraju biti pod krajnjom kontrolom korisnika. Korisnici bi trebali biti u mogućnosti odlučivati kome će odobriti izravan pristup svojim podacima i s kojim dopuštenjima i licencama takav pristup treba odobriti.",
    "Knowledge" : "Znanje",
    "of how the data is stored" : "o načinu pohrane podataka",
    "When the data is uploaded to a specific service provider, users should be informed about where that specific service provider stores the data, how long, in which jurisdiction the specific service provider operates, and which laws apply." : "Kada se podaci otpreme određenom davatelju usluga, korisnike bi trebalo obavijestiti gdje taj određeni davatelj usluga pohranjuje podatke, koliko dugo, u kojoj nadležnosti djeluje određeni davatelj usluga i koji se zakoni primjenjuju.",
    "Freedom" : "Sloboda",
    "to choose a platform" : "biranja platforme",
    "Users should always be able to extract their data from the service at any time without experiencing any vendor lock-in. Open standards for formats and protocols are necessary to guarantee this." : "Korisnici bi trebali uvijek biti u mogućnosti izdvojiti svoje podatke iz usluge u bilo kojem trenutku bez ikakvih uplitanja davatelja usluge. Otvoreni standardi formata i protokola nužni su kako bi se to zajamčilo.",
    "Learn more ↗" : "Saznajte više ↗",
    "Your data represents who you are and can easily be abused. We at Nextcloud believe that you have a right to decide what happens with your data. Nextcloud protects your rights as defined in the User Data Manifesto!" : "Vaši podaci predstavljaju vas i lako ih se može zloupotrijebiti. Mi u Nextcloudu vjerujemo da imate pravo odlučivati što će se dogoditi s vašim podacima. Nextcloud štiti vaša prava kako su definirana u Manifestu o podacima korisnika!",
    "Somaliland" : "Somaliland",
    "Andorra" : "Andora",
    "United Arab Emirates" : "Ujedinjeni Arapski Emirati",
    "Afghanistan" : "Afganistan",
    "Antigua and Barbuda" : "Antigva i Barbuda",
    "Anguilla" : "Angvila",
    "Albania" : "Albanija",
    "Armenia" : "Armenija",
    "Angola" : "Angola",
    "Antarctica" : "Antarktika",
    "Argentina" : "Argentina",
    "American Samoa" : "Američka Samoa",
    "Austria" : "Austrija",
    "Australia" : "Australija",
    "Aruba" : "Aruba",
    "Åland Islands" : "Ålandski otoci",
    "Azerbaijan" : "Azerbajdžan",
    "Bosnia and Herzegovina" : "Bosna i Hercegovina",
    "Barbados" : "Barbados",
    "Bangladesh" : "Bangladeš",
    "Belgium" : "Belgija",
    "Burkina Faso" : "Burkina Faso",
    "Bulgaria" : "Bugarska",
    "Bahrain" : "Bahrein",
    "Burundi" : "Burundi",
    "Benin" : "Benin",
    "Saint Barthélemy" : "Sveti Bartolomej",
    "Bermuda" : "Bermuda",
    "Brunei" : "Brunej",
    "Bolivia" : "Bolivija",
    "Bonaire, Sint Eustatius and Saba" : "Bonaire, Sveti Eustahije i Saba",
    "Brazil" : "Brazil",
    "Bahamas" : "Bahami",
    "Bhutan" : "Butan",
    "Bouvet Island" : "Otok Bouvet",
    "Botswana" : "Bocvana",
    "Belarus" : "Bjelorusija",
    "Belize" : "Belize",
    "Canada" : "Kanada",
    "Cocos (Keeling) Islands" : "Kokosov (Keeling) otok",
    "Democratic Republic of the Congo" : "Demokratska Republika Kongo",
    "Central African Republic" : "Srednjoafrička Republika",
    "Congo" : "Kongo",
    "Switzerland" : "Švicarska",
    "Cote d'Ivoire" : "Obala Bjelokosti",
    "Cook Islands" : "Cookovo Otočje",
    "Chile" : "Čile",
    "Cameroon" : "Kamerun",
    "China" : "Kina",
    "Colombia" : "Kolumbija",
    "Costa Rica" : "Kostarika",
    "Cuba" : "Kuba",
    "Cabo Verde" : "Zelenortska Republika",
    "Curaçao" : "Curaçao",
    "Christmas Island" : "Božićni Otok",
    "Cyprus" : "Cipar",
    "Czech" : "Češka",
    "Germany" : "Njemačka",
    "Djibouti" : "Džibuti",
    "Denmark" : "Danska",
    "Dominican Republic" : "Dominikanska Republika",
    "Algeria" : "Alžir",
    "Ecuador" : "Ekvador",
    "Estonia" : "Estonija",
    "Egypt" : "Egipat",
    "West Sahara" : "Zapadna Sahara",
    "Eritrea" : "Eritreja",
    "Spain" : "Španjolska",
    "Ethiopia" : "Etiopija",
    "Finland" : "Finska",
    "Fiji" : "Fidži",
    "Falkland Islands" : "Falklandski otoci",
    "Micronesia" : "Mikronezija",
    "Faroe Islands" : "Farski otoci",
    "France" : "Francuska",
    "Gabon" : "Gabon",
    "United Kingdom" : "Ujedinjeno Kraljevstvo",
    "Grenada" : "Grenada",
    "Georgia" : "Gruzija",
    "French Guiana" : "Francuska Gvajana",
    "Guernsey" : "Guernsey",
    "Ghana" : "Gana",
    "Gibraltar" : "Gibraltar",
    "Greenland" : "Grenland",
    "Gambia" : "Gambija",
    "Guinea" : "Gvineja",
    "Guadeloupe" : "Gvadalupa",
    "Equatorial Guinea" : "Ekvatorijalna Gvineja",
    "Greece" : "Grčka",
    "South Georgia and the South Sandwich Islands" : "Južna Georgija i otočje Južni Sandwich",
    "Guatemala" : "Gvatemala",
    "Guam" : "Guam",
    "Guinea-Bissau" : "Gvineja Bisau",
    "Guyana" : "Gvajana",
    "Hong Kong" : "Hong Kong",
    "Heard Island and McDonald Islands" : "Otok Heard i otočje McDonald",
    "Honduras" : "Honduras",
    "Croatia" : "Hrvatska",
    "Haiti" : "Haiti",
    "Hungary" : "Mađarska",
    "Indonesia" : "Indonezija",
    "Ireland" : "Irska",
    "Israel" : "Izrael",
    "Isle of Man" : "Otok Man",
    "India" : "Indija",
    "British Indian Ocean Territory" : "Britanski Indijskooceanski teritorij",
    "Iraq" : "Irak",
    "Iran" : "Iran",
    "Iceland" : "Island",
    "Italy" : "Italija",
    "Jamaica" : "Jamajka",
    "Jordan" : "Jordan",
    "Japan" : "Japan",
    "Kenya" : "Kenija",
    "Kyrgyzstan" : "Kirgistan",
    "Cambodia" : "Kambodža",
    "Kiribati" : "Kiribati",
    "Comores" : "Komori",
    "Saint Kitts and Nevis" : "Sveti Kristofor i Nevis",
    "North Korea" : "Sjeverna Koreja",
    "South Korea" : "Južna Koreja",
    "Kuwait" : "Kuvajt",
    "Cayman Islands" : "Kajmanski Otoci",
    "Kazakhstan" : "Kazahstan",
    "Laos" : "Laos",
    "Lebanon" : "Libanon",
    "Saint Lucia" : "Sveta Lucija",
    "Liechtenstein" : "Lihtenštajn",
    "Sri Lanka" : "Šri Lanka",
    "Liberia" : "Liberija",
    "Lesotho" : "Lesoto",
    "Lithuania" : "Litva",
    "Luxembourg" : "Luksemburg",
    "Latvia" : "Latvija",
    "Libya" : "Libija",
    "Morocco" : "Maroko",
    "Monaco" : "Monako",
    "Moldova" : "Moldavija",
    "Montenegro" : "Crna Gora",
    "Saint Martin" : "Sveti Martin",
    "Madagascar" : "Madagaskar",
    "Marshall Islands" : "Maršalovi Otoci",
    "Macedonia" : "Makedonija",
    "Mali" : "Mali",
    "Myanmar" : "Mjanmar",
    "Mongolia" : "Mongolija",
    "Macao" : "Makao",
    "Northern Mariana Islands" : "Sjevernomarijanski otoci",
    "Mauritania" : "Mauritanija",
    "Montserrat" : "Montserrat",
    "Malta" : "Malta",
    "Mauritius" : "Mauricijus",
    "Maldives" : "Maldivi",
    "Malawi" : "Malavi",
    "Mexico" : "Meksiko",
    "Malaysia" : "Malezija",
    "Mozambique" : "Mozambik",
    "Namibia" : "Namibija",
    "New Caledonia" : "Nova Kaledonija",
    "Niger" : "Niger",
    "Norfolk Island" : "Otok Norfolk",
    "Nigeria" : "Nigerija",
    "Nicaragua" : "Nikaragva",
    "Netherlands" : "Nizozemska",
    "Norway" : "Norveška",
    "Nepal" : "Nepal",
    "Nauru" : "Nauru",
    "Niue" : "Niue",
    "New Zealand" : "Novi Zeland",
    "Oman" : "Oman",
    "Panama" : "Panama",
    "Peru" : "Peru",
    "French Polynesia" : "Francuska Polinezija",
    "Papua New Guinea" : "Papua Nova Gvineja",
    "Philippines" : "Filipini",
    "Pakistan" : "Pakistan",
    "Poland" : "Poljska",
    "Saint Pierre and Miquelon" : "Sveti Petar i Mikelon",
    "Pitcairn" : "Pitcairn",
    "Puerto Rico" : "Portoriko",
    "Palestine" : "Palestina",
    "Portugal" : "Portugal",
    "Palau" : "Palau",
    "Paraguay" : "Paragvaj",
    "Qatar" : "Katar",
    "Réunion" : "Réunion",
    "Romania" : "Rumunjska",
    "Serbia" : "Srbija",
    "Russia" : "Rusija",
    "Rwanda" : "Ruanda",
    "Saudi Arabia" : "Saudijska Arabija",
    "Solomon Islands" : "Salomonski otoci",
    "Seychelles" : "Sejšeli",
    "Sudan" : "Sudan",
    "Sweden" : "Švedska",
    "Singapore" : "Singapur",
    "Saint Helena, Ascension and Tristan da Cunha" : "Sveta Helena, Ascension i Tristan da Cunha",
    "Slovenia" : "Slovenija",
    "Svalbard and Jan Mayen" : "Svalbard i Jan Mayen",
    "Slovakia" : "Slovačka",
    "Sierra Leone" : "Sijera Leone",
    "San Marino" : "San Marino",
    "Senegal" : "Senegal",
    "Somalia" : "Somalija",
    "Suriname" : "Surinam",
    "South Sudan" : "Južni Sudan",
    "Sao Tome and Principe" : "Sveti Toma i Princip",
    "El Salvador" : "El Salvador",
    "Sint Maarten" : "Sint Maarten",
    "Syria" : "Sirija",
    "Swaziland" : "Esvatini",
    "Turks and Caicos Islands" : "Otoci Turks i Caicos",
    "Chad" : "Čad",
    "Fr. S. Antarctic Lands" : "Francuski južni i antarktički teritoriji",
    "Togo" : "Togo",
    "Thailand" : "Tajland",
    "Tajikistan" : "Tadžikistan",
    "Tokelau" : "Tokelau",
    "Timor-Leste" : "Istočni Timor",
    "Turkmenistan" : "Turkmenistan",
    "Tunisia" : "Tunis",
    "Tonga" : "Tonga",
    "Turkey" : "Turska",
    "Trinidad and Tobago" : "Trinidad i Tobago",
    "Tuvalu" : "Tuvalu",
    "Taiwan" : "Tajvan",
    "Tanzania" : "Tanzanija",
    "Ukraine" : "Ukrajina",
    "Uganda" : "Uganda",
    "United States Minor Outlying Islands" : "Mali udaljeni otoci SAD-a",
    "United States" : "Sjedinjene Američke Države",
    "Uruguay" : "Urugvaj",
    "Uzbekistan" : "Uzbekistan",
    "Holy See" : "Sveta Stolica",
    "Saint Vincent and the Grenadines" : "Sveti Vincent i Grenadini",
    "Venezuela" : "Venezuela",
    "Virgin Islands (British)" : "Djevičanski otoci (britanski)",
    "Virgin Islands (U.S.)" : "Djevičanski otoci (SAD)",
    "Vietnam" : "Vijetnam",
    "Vanuatu" : "Vanuatu",
    "Wallis and Futuna" : "Wallis i Futuna",
    "Samoa" : "Samoa",
    "Yemen" : "Jemen",
    "Mayotte" : "Mayotte",
    "South Africa" : "Južna Afrika",
    "Zambia" : "Zambija",
    "Zimbabwe" : "Zimbabve",
    "You don't have any shares with individual users." : "Nemate dijeljenja s pojedinačnim korisnicima.",
    "Defining basic rights for people to control their own data in the internet age" : "Definiranje osnovnih prava koje osobama omogućuju nadzor nad vlastitim podacima u doba interneta",
    "People you shared with" : "Osobe s kojima ih dijelite",
    "Read the privacy policy." : "Pročitajte pravila o privatnosti."
},
"nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
